"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseRecord = void 0;
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class BaseRecord {
    constructor(obj) {
        this.idBase = obj.idBase;
        this.name = obj.name;
        this.price = obj.price;
        this.count = obj.count;
        this.seedId = obj.seedId;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.idBase) {
                this.idBase = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `bases`(`idBase`, `name`, `price`, `count`, `seedId`) VALUES(:idBase, :name, :price, :count, :seedId)", {
                idBase: this.idBase,
                name: this.name,
                price: this.price,
                count: this.count,
                seedId: this.seedId,
            });
            return this.idBase;
        });
    }
    static listAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute("SELECT * FROM `bases` ORDER BY `name` ASC");
            return result.map(obj => new BaseRecord(obj));
        });
    }
    static getOne(idBase) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `bases` WHERE `idBase` = :idBase", {
                idBase,
            }));
            return results.length === 0 ? null : new BaseRecord(results[0]);
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `bases` SET `name` = :name, `seedId` = :seedId, `count` = :count WHERE `idBase` = :idBase", {
                idBase: this.idBase,
                name: this.name,
                seedId: this.seedId,
                count: this.count,
            });
        });
    }
    delete(idBase) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `bases` WHERE `idBase` = :idBase", {
                idBase: this.idBase,
            });
        });
    }
    countGivenBases() {
        return __awaiter(this, void 0, void 0, function* () {
            const [[{ count }]] = yield db_1.pool.execute("SELECT COUNT(*) AS `count` FROM `bases` WHERE `idBase` = :idBase ", {
                idBase: this.idBase,
            });
            return count;
        });
    }
}
exports.BaseRecord = BaseRecord;
//# sourceMappingURL=base.record.js.map