"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SeedRecord = void 0;
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
class SeedRecord {
    constructor(obj) {
        this.idSeed = obj.idSeed;
        this.name = obj.name;
        this.price = obj.price;
        this.count = obj.count;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.idSeed) {
                this.idSeed = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `seeds`(`idSeed`,`name`,`price`, `count`) VALUES(:idSeed, :name, :price, :count)", {
                idSeed: this.idSeed,
                name: this.name,
                price: this.price,
                count: this.count,
            });
            return this.idSeed;
        });
    }
    static listAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `seeds` ORDER BY `name` ASC");
            return results.map(obj => new SeedRecord(obj));
        });
    }
    static getOne(idSeed) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute("SELECT * FROM `seeds` WHERE `idSeed` = :idSeed", {
                idSeed,
            });
            return result.length === 0 ? null : new SeedRecord(result[0]);
        });
    }
    // Add update method
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            if (typeof this.count !== 'undefined') {
                yield db_1.pool.execute("UPDATE `seeds` SET `count` = :count  WHERE `idSeed` = :idSeed", {
                    idSeed: this.idSeed,
                    count: this.count,
                });
            }
            else {
                console.error('Count is undefined. Cannot update record.');
            }
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `seeds` WHERE `idSeed` = :idSeed ", {
                idSeed: this.idSeed,
            });
        });
    }
    countGivenSeeds() {
        return __awaiter(this, void 0, void 0, function* () {
            const [[{ count }]] = yield db_1.pool.execute("SELECT COUNT(*) AS `count` FROM `bases` WHERE `seedId` = :idSeed ", {
                idSeed: this.idSeed,
            });
            return count;
        });
    }
}
exports.SeedRecord = SeedRecord;
//# sourceMappingURL=seed.record.js.map